@@ -70,7 +70,7 @@ impl Clone for CachedExpensiveCount {
 fn main() {
     let mut rng = SmallRng::from_entropy();
     let genotype = BinaryGenotype::builder()
-        .with_gene_size(100)
+        .with_genes_size(100)
         .build()
         .unwrap();
 
@@ -86,9 +86,8 @@ fn main() {
         .with_fitness(CachedExpensiveCount::new(1000, 1500))
         .with_crossover(CrossoverClone(true))
         .with_compete(CompeteTournament(4))
-        .build()
-        .unwrap()
-        .call(&mut rng);
+        .call(&mut rng)
+        .unwrap();
 
     println!("{}", evolve);
 }
