@@ -6,8 +6,8 @@ use rand::rngs::SmallRng;
 fn main() {
     let mut rng = SmallRng::from_entropy();
     let genotype = ContinuousGenotype::builder()
-        .with_gene_size(100)
-        .with_gene_range(0.0..1.0)
+        .with_genes_size(100)
+        .with_allele_range(0.0..1.0)
         .build()
         .unwrap();
 
@@ -21,11 +21,10 @@ fn main() {
         .with_degeneration_range(0.0001..1.0000)
         .with_mutate(MutateOnce(0.2))
         .with_fitness(SumContinuousGenotype)
-        .with_crossover(CrossoverAll(true))
+        .with_crossover(CrossoverUniform(true))
         .with_compete(CompeteTournament(4))
-        .build()
-        .unwrap()
-        .call(&mut rng);
+        .call(&mut rng)
+        .unwrap();
 
     println!("{}", evolve);
 }
