@@ -3,7 +3,7 @@ use genetic_algorithm::fitness::placeholders::CountTrue;
 
 fn main() {
     let genotype = BinaryGenotype::builder()
-        .with_gene_size(100)
+        .with_genes_size(100)
         .build()
         .unwrap();
     let evolve = Evolve::builder()
@@ -11,7 +11,7 @@ fn main() {
         .with_population_size(1000)
         .with_mutate(MutateOnce(0.2))
         .with_fitness(CountTrue)
-        .with_crossover(CrossoverSingle(true))
+        .with_crossover(CrossoverSingleGene(true))
         .with_compete(CompeteTournament(4))
         .build();
 
