@@ -30,9 +30,11 @@ impl Fitness for NQueensFitness {
 }
 
 fn main() {
+    const BOARD_SIZE: u8 = 64;
+
     let mut rng = SmallRng::from_entropy();
     let genotype = UniqueDiscreteGenotype::builder()
-        .with_gene_values((0..64).collect())
+        .with_allele_values((0..BOARD_SIZE).collect())
         .build()
         .unwrap();
 
@@ -48,9 +50,16 @@ fn main() {
         .with_fitness(NQueensFitness)
         .with_crossover(CrossoverClone(true))
         .with_compete(CompeteElite)
-        .build()
-        .unwrap()
-        .call(&mut rng);
+        .call(&mut rng)
+        .unwrap();
 
     println!("{}", evolve);
+
+    if let Some(best_chromosome) = evolve.best_chromosome {
+        for gene in best_chromosome.genes {
+            let mut chars: Vec<char> = (0..BOARD_SIZE).map(|_| '.').collect();
+            chars[gene as usize] = 'X';
+            println!("{}", String::from_iter(chars));
+        }
+    }
 }
