@@ -20,7 +20,7 @@ criterion_main!(benches);
 fn run() {
     let mut rng = SmallRng::from_entropy();
     let genotype = BinaryGenotype::builder()
-        .with_gene_size(100)
+        .with_genes_size(100)
         .build()
         .unwrap();
 
@@ -31,11 +31,10 @@ fn run() {
         .with_target_fitness_score(100)
         .with_mutate(MutateOnce(0.2))
         .with_fitness(CountTrue)
-        .with_crossover(CrossoverAll(true))
+        .with_crossover(CrossoverUniform(true))
         .with_compete(CompeteTournament(4))
-        .build()
-        .unwrap()
-        .call(&mut rng);
+        .call(&mut rng)
+        .unwrap();
 
     println!("{}", evolve);
 }
