@@ -3,7 +3,9 @@ pub use crate::chromosome::{Chromosome, GenesKey};
 #[doc(no_inline)]
 pub use crate::compete::{CompeteElite, CompeteTournament};
 #[doc(no_inline)]
-pub use crate::crossover::{CrossoverAll, CrossoverClone, CrossoverRange, CrossoverSingle};
+pub use crate::crossover::{
+    CrossoverClone, CrossoverSingleGene, CrossoverSinglePoint, CrossoverUniform,
+};
 #[doc(no_inline)]
 pub use crate::evolve::{Evolve, EvolveBuilder, TryFromEvolveBuilderError};
 #[doc(no_inline)]
@@ -11,7 +13,7 @@ pub use crate::fitness::{Fitness, FitnessOrdering, FitnessValue};
 #[doc(no_inline)]
 pub use crate::genotype::{
     BinaryGenotype, ContinuousGenotype, DiscreteGenotype, Genotype, GenotypeBuilder,
-    MultiContinuousGenotype, MultiDiscreteGenotype, SetGenotype, TryFromGenotypeBuilderError,
+    MultiContinuousGenotype, MultiDiscreteGenotype, TryFromGenotypeBuilderError,
     UniqueDiscreteGenotype,
 };
 #[doc(no_inline)]
