@@ -10,12 +10,7 @@ use crate::population::Population;
 use rand::Rng;
 
 pub trait Mutate: Clone + std::fmt::Debug {
-    fn call<T: Genotype, R: Rng>(
-        &self,
-        genotype: &T,
-        population: Population<T>,
-        rng: &mut R,
-    ) -> Population<T>;
+    fn call<T: Genotype, R: Rng>(&self, genotype: &T, population: &mut Population<T>, rng: &mut R);
 }
 
 #[derive(Clone, Debug)]
@@ -28,12 +23,7 @@ pub type MutationProbability = f32;
 #[derive(Clone, Debug)]
 pub struct MutateDispatch(pub Mutates, pub MutationProbability);
 impl Mutate for MutateDispatch {
-    fn call<T: Genotype, R: Rng>(
-        &self,
-        genotype: &T,
-        population: Population<T>,
-        rng: &mut R,
-    ) -> Population<T> {
+    fn call<T: Genotype, R: Rng>(&self, genotype: &T, population: &mut Population<T>, rng: &mut R) {
         match self.0 {
             Mutates::Once => MutateOnce(self.1).call(genotype, population, rng),
         }
