@@ -9,18 +9,12 @@ use rand::Rng;
 #[derive(Debug, Clone)]
 pub struct Once(pub MutationProbability);
 impl Mutate for Once {
-    fn call<T: Genotype, R: Rng>(
-        &self,
-        genotype: &T,
-        mut population: Population<T>,
-        rng: &mut R,
-    ) -> Population<T> {
+    fn call<T: Genotype, R: Rng>(&self, genotype: &T, population: &mut Population<T>, rng: &mut R) {
         let bool_sampler = Bernoulli::new(self.0 as f64).unwrap();
         for chromosome in &mut population.chromosomes {
             if bool_sampler.sample(rng) {
                 genotype.mutate_chromosome(chromosome, rng);
             }
         }
-        population
     }
 }
