@@ -5,19 +5,42 @@ use genetic_algorithm::genotype::{BinaryGenotype, Genotype};
 
 #[test]
 fn population_odd() {
-    let genotype = BinaryGenotype::builder().with_gene_size(3).build().unwrap();
+    let genotype = BinaryGenotype::builder().with_genes_size(3).build().unwrap();
 
-    let population = build::population(vec![
+    let population = &mut build::population(vec![
         vec![true, true, true],
         vec![false, false, false],
         vec![true, true, true],
     ]);
 
     let mut rng = SmallRng::seed_from_u64(0);
-    let population = CrossoverClone(true).call(&genotype, population, &mut rng);
+    CrossoverClone(false).call(&genotype, population, &mut rng);
 
     assert_eq!(
-        inspect::population(&population),
+        inspect::population(population),
+        vec![
+            vec![true, true, true],
+            vec![false, false, false],
+            vec![true, true, true],
+        ]
+    )
+}
+
+#[test]
+fn population_odd_keep_parents() {
+    let genotype = BinaryGenotype::builder().with_genes_size(3).build().unwrap();
+
+    let population = &mut build::population(vec![
+        vec![true, true, true],
+        vec![false, false, false],
+        vec![true, true, true],
+    ]);
+
+    let mut rng = SmallRng::seed_from_u64(0);
+    CrossoverClone(true).call(&genotype, population, &mut rng);
+
+    assert_eq!(
+        inspect::population(population),
         vec![
             vec![true, true, true],
             vec![false, false, false],
@@ -31,15 +54,15 @@ fn population_odd() {
 
 #[test]
 fn population_size_one() {
-    let genotype = BinaryGenotype::builder().with_gene_size(5).build().unwrap();
+    let genotype = BinaryGenotype::builder().with_genes_size(5).build().unwrap();
 
-    let population = build::population(vec![vec![true, false, true, false, true]]);
+    let population = &mut build::population(vec![vec![true, false, true, false, true]]);
 
     let mut rng = SmallRng::seed_from_u64(0);
-    let population = CrossoverClone(false).call(&genotype, population, &mut rng);
+    CrossoverClone(false).call(&genotype, population, &mut rng);
 
     assert_eq!(
-        inspect::population(&population),
+        inspect::population(population),
         vec![vec![true, false, true, false, true]]
     )
 }
