@@ -4,7 +4,7 @@ mod support;
 mod evolve_tests {
     use crate::support::*;
     use genetic_algorithm::compete::CompeteTournament;
-    use genetic_algorithm::crossover::CrossoverSingle;
+    use genetic_algorithm::crossover::CrossoverSingleGene;
     use genetic_algorithm::evolve::{Evolve, TryFromEvolveBuilderError};
     use genetic_algorithm::fitness::placeholders::{
         CountTrue, SumContinuousGenotype, SumDiscreteGenotype, SumMultiDiscreteGenotype,
@@ -20,7 +20,7 @@ mod evolve_tests {
     #[test]
     fn build_invalid_missing_ending_condition() {
         let genotype = BinaryGenotype::builder()
-            .with_gene_size(10)
+            .with_genes_size(10)
             .build()
             .unwrap();
         let evolve = Evolve::builder()
@@ -28,7 +28,7 @@ mod evolve_tests {
             .with_population_size(100)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(CountTrue)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
             .build();
 
@@ -44,7 +44,7 @@ mod evolve_tests {
     #[test]
     fn build_invalid_incompatible_genotype_and_crossover() {
         let genotype = UniqueDiscreteGenotype::builder()
-            .with_gene_values((0..10).collect())
+            .with_allele_values((0..10).collect())
             .build()
             .unwrap();
         let evolve = Evolve::builder()
@@ -53,7 +53,7 @@ mod evolve_tests {
             .with_max_stale_generations(20)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(SumUniqueDiscreteGenotype)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
             .build();
 
@@ -69,7 +69,7 @@ mod evolve_tests {
     #[test]
     fn call_binary_max_stale_generations_maximize() {
         let genotype = BinaryGenotype::builder()
-            .with_gene_size(10)
+            .with_genes_size(10)
             .build()
             .unwrap();
         let mut rng = SmallRng::seed_from_u64(0);
@@ -79,11 +79,10 @@ mod evolve_tests {
             .with_max_stale_generations(20)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(CountTrue)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
-            .build()
-            .unwrap()
-            .call(&mut rng);
+            .call(&mut rng)
+            .unwrap();
 
         let best_chromosome = evolve.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -98,7 +97,7 @@ mod evolve_tests {
     #[test]
     fn call_binary_max_stale_generations_minimize() {
         let genotype = BinaryGenotype::builder()
-            .with_gene_size(10)
+            .with_genes_size(10)
             .build()
             .unwrap();
         let mut rng = SmallRng::seed_from_u64(0);
@@ -109,11 +108,10 @@ mod evolve_tests {
             .with_max_stale_generations(20)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(CountTrue)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
-            .build()
-            .unwrap()
-            .call(&mut rng);
+            .call(&mut rng)
+            .unwrap();
 
         let best_chromosome = evolve.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -128,7 +126,7 @@ mod evolve_tests {
     #[test]
     fn call_binary_target_fitness_score_maximize() {
         let genotype = BinaryGenotype::builder()
-            .with_gene_size(10)
+            .with_genes_size(10)
             .build()
             .unwrap();
         let mut rng = SmallRng::seed_from_u64(0);
@@ -138,11 +136,10 @@ mod evolve_tests {
             .with_target_fitness_score(8)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(CountTrue)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
-            .build()
-            .unwrap()
-            .call(&mut rng);
+            .call(&mut rng)
+            .unwrap();
 
         let best_chromosome = evolve.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -150,14 +147,14 @@ mod evolve_tests {
         assert_eq!(best_chromosome.fitness_score, Some(9));
         assert_eq!(
             inspect::chromosome(&best_chromosome),
-            vec![true, true, true, true, true, true, true, true, true, false]
+            vec![true, true, true, true, true, true, true, false, true, true]
         );
     }
 
     #[test]
     fn call_binary_target_fitness_score_minimize() {
         let genotype = BinaryGenotype::builder()
-            .with_gene_size(10)
+            .with_genes_size(10)
             .build()
             .unwrap();
         let mut rng = SmallRng::seed_from_u64(0);
@@ -168,11 +165,10 @@ mod evolve_tests {
             .with_target_fitness_score(0)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(CountTrue)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
-            .build()
-            .unwrap()
-            .call(&mut rng);
+            .call(&mut rng)
+            .unwrap();
 
         let best_chromosome = evolve.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -187,7 +183,7 @@ mod evolve_tests {
     #[test]
     fn call_binary_degeneration_range() {
         let genotype = BinaryGenotype::builder()
-            .with_gene_size(10)
+            .with_genes_size(10)
             .build()
             .unwrap();
         let mut rng = SmallRng::seed_from_u64(0);
@@ -198,11 +194,10 @@ mod evolve_tests {
             .with_degeneration_range(0.0001..1.0000)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(CountTrue)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
-            .build()
-            .unwrap()
-            .call(&mut rng);
+            .call(&mut rng)
+            .unwrap();
 
         let best_chromosome = evolve.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -217,8 +212,8 @@ mod evolve_tests {
     #[test]
     fn call_continuous() {
         let genotype = ContinuousGenotype::builder()
-            .with_gene_size(10)
-            .with_gene_range(0.0..1.0)
+            .with_genes_size(10)
+            .with_allele_range(0.0..1.0)
             .build()
             .unwrap();
         let mut rng = SmallRng::seed_from_u64(0);
@@ -228,11 +223,10 @@ mod evolve_tests {
             .with_max_stale_generations(20)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(SumContinuousGenotype)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
-            .build()
-            .unwrap()
-            .call(&mut rng);
+            .call(&mut rng)
+            .unwrap();
 
         let best_chromosome = evolve.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -241,8 +235,8 @@ mod evolve_tests {
         assert_eq!(
             inspect::chromosome(&best_chromosome),
             vec![
-                0.9651495, 0.9817951, 0.9798802, 0.82838106, 0.7647406, 0.93074965, 0.87062526,
-                0.90698075, 0.9505005, 0.99518645
+                0.99824846, 0.9817951, 0.86975336, 0.82838106, 0.98283255, 0.9091289, 0.9379811,
+                0.90698075, 0.6531458, 0.99518645
             ]
         );
     }
@@ -250,8 +244,8 @@ mod evolve_tests {
     #[test]
     fn call_discrete() {
         let genotype = DiscreteGenotype::builder()
-            .with_gene_size(10)
-            .with_gene_values((0..4).collect())
+            .with_genes_size(10)
+            .with_allele_values((0..4).collect())
             .build()
             .unwrap();
 
@@ -262,11 +256,10 @@ mod evolve_tests {
             .with_max_stale_generations(20)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(SumDiscreteGenotype)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
-            .build()
-            .unwrap()
-            .call(&mut rng);
+            .call(&mut rng)
+            .unwrap();
 
         let best_chromosome = evolve.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -281,7 +274,7 @@ mod evolve_tests {
     #[test]
     fn call_multi_discrete() {
         let genotype = MultiDiscreteGenotype::builder()
-            .with_gene_multi_values(vec![
+            .with_allele_multi_values(vec![
                 vec![0, 1, 2, 3, 4],
                 vec![0, 1],
                 vec![0],
@@ -296,11 +289,10 @@ mod evolve_tests {
             .with_max_stale_generations(20)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(SumMultiDiscreteGenotype)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
-            .build()
-            .unwrap()
-            .call(&mut rng);
+            .call(&mut rng)
+            .unwrap();
 
         let best_chromosome = evolve.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -311,7 +303,10 @@ mod evolve_tests {
 
     #[test]
     fn population_factory_binary() {
-        let genotype = BinaryGenotype::builder().with_gene_size(4).build().unwrap();
+        let genotype = BinaryGenotype::builder()
+            .with_genes_size(4)
+            .build()
+            .unwrap();
         let mut rng = SmallRng::seed_from_u64(0);
         let mut evolve = Evolve::builder()
             .with_genotype(genotype)
@@ -319,7 +314,7 @@ mod evolve_tests {
             .with_max_stale_generations(20)
             .with_mutate(MutateOnce(0.1))
             .with_fitness(CountTrue)
-            .with_crossover(CrossoverSingle(true))
+            .with_crossover(CrossoverSingleGene(true))
             .with_compete(CompeteTournament(4))
             .build()
             .unwrap();
