@@ -6,8 +6,8 @@ use genetic_algorithm::genotype::{ContinuousGenotype, Genotype};
 fn general() {
     let mut rng = SmallRng::seed_from_u64(0);
     let genotype = ContinuousGenotype::builder()
-        .with_gene_size(10)
-        .with_gene_range(0.0..1.0)
+        .with_genes_size(10)
+        .with_allele_range(0.0..1.0)
         .build()
         .unwrap();
 
