@@ -21,16 +21,16 @@ mod meta_tests {
             MutateDispatch(Mutates::Once, 0.2),
         ];
         let crossovers = vec![
-            CrossoverDispatch(Crossovers::Single, true),
-            CrossoverDispatch(Crossovers::Single, false),
-            CrossoverDispatch(Crossovers::Range, true),
+            CrossoverDispatch(Crossovers::SingleGene, true),
+            CrossoverDispatch(Crossovers::SingleGene, false),
+            CrossoverDispatch(Crossovers::SinglePoint, true),
         ];
         let competes = vec![
             CompeteDispatch(Competes::Elite, 0),
             CompeteDispatch(Competes::Tournament, 4),
         ];
         let genotype = BinaryGenotype::builder()
-            .with_gene_size(10)
+            .with_genes_size(10)
             .build()
             .unwrap();
         let fitness = CountTrue;
