@@ -17,14 +17,13 @@ mod permutate_tests {
 
     #[test]
     fn call_binary_maximize() {
-        let genotype = BinaryGenotype::builder().with_gene_size(5).build().unwrap();
+        let genotype = BinaryGenotype::builder().with_genes_size(5).build().unwrap();
 
         let permutate = Permutate::builder()
             .with_genotype(genotype)
             .with_fitness(CountTrue)
-            .build()
-            .unwrap()
-            .call();
+            .call()
+            .unwrap();
 
         let best_chromosome = permutate.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -38,15 +37,14 @@ mod permutate_tests {
 
     #[test]
     fn call_binary_minimize() {
-        let genotype = BinaryGenotype::builder().with_gene_size(5).build().unwrap();
+        let genotype = BinaryGenotype::builder().with_genes_size(5).build().unwrap();
 
         let permutate = Permutate::builder()
             .with_genotype(genotype)
             .with_fitness_ordering(FitnessOrdering::Minimize)
             .with_fitness(CountTrue)
-            .build()
-            .unwrap()
-            .call();
+            .call()
+            .unwrap();
 
         let best_chromosome = permutate.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -61,17 +59,16 @@ mod permutate_tests {
     #[test]
     fn call_discrete() {
         let genotype = DiscreteGenotype::builder()
-            .with_gene_size(5)
-            .with_gene_values((0..10).collect())
+            .with_genes_size(5)
+            .with_allele_values((0..10).collect())
             .build()
             .unwrap();
 
         let permutate = Permutate::builder()
             .with_genotype(genotype)
             .with_fitness(SumDiscreteGenotype)
-            .build()
-            .unwrap()
-            .call();
+            .call()
+            .unwrap();
 
         let best_chromosome = permutate.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
@@ -83,7 +80,7 @@ mod permutate_tests {
     #[test]
     fn call_multi_discrete() {
         let genotype = MultiDiscreteGenotype::builder()
-            .with_gene_multi_values(vec![
+            .with_allele_multi_values(vec![
                 vec![0, 1, 2, 3, 4],
                 vec![0, 1],
                 vec![0],
@@ -95,9 +92,8 @@ mod permutate_tests {
         let permutate = Permutate::builder()
             .with_genotype(genotype)
             .with_fitness(SumMultiDiscreteGenotype)
-            .build()
-            .unwrap()
-            .call();
+            .call()
+            .unwrap();
 
         let best_chromosome = permutate.best_chromosome.unwrap();
         println!("{:#?}", best_chromosome);
