@@ -4,26 +4,26 @@ use genetic_algorithm::genotype::Genotype;
 use genetic_algorithm::population::Population;
 
 #[allow(dead_code)]
-pub fn chromosome<T: Genotype>(chromosome: &Chromosome<T>) -> Vec<T::Gene> {
+pub fn chromosome<T: Genotype>(chromosome: &Chromosome<T>) -> Vec<T::Allele> {
     chromosome.genes.clone()
 }
 
 #[allow(dead_code)]
 pub fn chromosome_with_fitness_score<T: Genotype>(
     chromosome: &Chromosome<T>,
-) -> (Vec<T::Gene>, Option<FitnessValue>) {
+) -> (Vec<T::Allele>, Option<FitnessValue>) {
     (chromosome.genes.clone(), chromosome.fitness_score)
 }
 
 #[allow(dead_code)]
-pub fn chromosomes<T: Genotype>(chromosomes: &Vec<Chromosome<T>>) -> Vec<Vec<T::Gene>> {
+pub fn chromosomes<T: Genotype>(chromosomes: &Vec<Chromosome<T>>) -> Vec<Vec<T::Allele>> {
     chromosomes.iter().map(|c| chromosome(&c)).collect()
 }
 
 #[allow(dead_code)]
 pub fn chromosomes_with_fitness_score<T: Genotype>(
     chromosomes: &Vec<Chromosome<T>>,
-) -> Vec<(Vec<T::Gene>, Option<FitnessValue>)> {
+) -> Vec<(Vec<T::Allele>, Option<FitnessValue>)> {
     chromosomes
         .iter()
         .map(|c| chromosome_with_fitness_score(&c))
@@ -31,7 +31,7 @@ pub fn chromosomes_with_fitness_score<T: Genotype>(
 }
 
 #[allow(dead_code)]
-pub fn population<T: Genotype>(population: &Population<T>) -> Vec<Vec<T::Gene>> {
+pub fn population<T: Genotype>(population: &Population<T>) -> Vec<Vec<T::Allele>> {
     population
         .chromosomes
         .iter()
@@ -42,7 +42,7 @@ pub fn population<T: Genotype>(population: &Population<T>) -> Vec<Vec<T::Gene>>
 #[allow(dead_code)]
 pub fn population_with_fitness_scores<T: Genotype>(
     population: &Population<T>,
-) -> Vec<(Vec<T::Gene>, Option<FitnessValue>)> {
+) -> Vec<(Vec<T::Allele>, Option<FitnessValue>)> {
     population
         .chromosomes
         .iter()
